@@ -5,7 +5,7 @@ import platform
 import itertools
 
 import pytest
-from pkg_resources.extern import packaging
+from pkg_resources.extern.packaging.specifiers import SpecifierSet
 
 import pkg_resources
 from pkg_resources import (
@@ -35,7 +35,7 @@ class Metadata(pkg_resources.EmptyProvider):
     def __init__(self, *pairs):
         self.metadata = dict(pairs)
 
-    def has_metadata(self, name):
+    def has_metadata(self, name) -> bool:
         return name in self.metadata
 
     def get_metadata(self, name):
@@ -567,7 +567,7 @@ class TestRequirements:
         assert hash(r1) == hash((
             "twisted",
             None,
-            packaging.specifiers.SpecifierSet(">=1.2"),
+            SpecifierSet(">=1.2"),
             frozenset(["foo", "bar"]),
             None,
         ))
@@ -576,7 +576,7 @@ class TestRequirements:
         ) == hash((
             "twisted",
             "https://localhost/twisted.zip",
-            packaging.specifiers.SpecifierSet(),
+            SpecifierSet(),
             frozenset(),
             None,
         ))
