@@ -1,13 +1,14 @@
 """Tests for distutils.command.build_scripts."""
 
 import os
-
+import textwrap
+from distutils import sysconfig
 from distutils.command.build_scripts import build_scripts
 from distutils.core import Distribution
-from distutils import sysconfig
-
 from distutils.tests import support
 
+import jaraco.path
+
 
 class TestBuildScripts(support.TempdirManager):
     def test_default_settings(self):
@@ -45,38 +46,27 @@ class TestBuildScripts(support.TempdirManager):
         )
         return build_scripts(dist)
 
-    def write_sample_scripts(self, dir):
-        expected = []
-        expected.append("script1.py")
-        self.write_script(
-            dir,
-            "script1.py",
-            (
-                "#! /usr/bin/env python2.3\n"
-                "# bogus script w/ Python sh-bang\n"
-                "pass\n"
-            ),
-        )
-        expected.append("script2.py")
-        self.write_script(
-            dir,
-            "script2.py",
-            ("#!/usr/bin/python\n" "# bogus script w/ Python sh-bang\n" "pass\n"),
-        )
-        expected.append("shell.sh")
-        self.write_script(
-            dir,
-            "shell.sh",
-            ("#!/bin/sh\n" "# bogus shell script w/ sh-bang\n" "exit 0\n"),
-        )
-        return expected
-
-    def write_script(self, dir, name, text):
-        f = open(os.path.join(dir, name), "w")
-        try:
-            f.write(text)
-        finally:
-            f.close()
+    @staticmethod
+    def write_sample_scripts(dir):
+        spec = {
+            'script1.py': textwrap.dedent("""
+                #! /usr/bin/env python2.3
+                # bogus script w/ Python sh-bang
+                pass
+                """).lstrip(),
+            'script2.py': textwrap.dedent("""
+                #!/usr/bin/python
+                # bogus script w/ Python sh-bang
+                pass
+                """).lstrip(),
+            'shell.sh': textwrap.dedent("""
+                #!/bin/sh
+                # bogus shell script w/ sh-bang
+                exit 0
+                """).lstrip(),
+        }
+        jaraco.path.build(spec, dir)
+        return list(spec)
 
     def test_version_int(self):
         source = self.mkdtemp()
@@ -88,7 +78,7 @@ class TestBuildScripts(support.TempdirManager):
         )
         cmd.finalize_options()
 
-        # http://bugs.python.org/issue4524
+        # https://bugs.python.org/issue4524
         #
         # On linux-g++-32 with command line `./configure --enable-ipv6
         # --with-suffix=3`, python is compiled okay but the build scripts
