@@ -79,7 +79,8 @@ class TestEggInfo:
     @staticmethod
     def _extract_mv_version(pkg_info_lines: List[str]) -> Tuple[int, int]:
         version_str = pkg_info_lines[0].split(' ')[1]
-        return tuple(map(int, version_str.split('.')[:2]))
+        major, minor = map(int, version_str.split('.')[:2])
+        return major, minor
 
     def test_egg_info_save_version_info_setup_empty(self, tmpdir_cwd, env):
         """
@@ -93,7 +94,7 @@ class TestEggInfo:
         ei.initialize_options()
         ei.save_version_info(setup_cfg)
 
-        with open(setup_cfg, 'r') as f:
+        with open(setup_cfg, 'r', encoding="utf-8") as f:
             content = f.read()
 
         assert '[egg_info]' in content
@@ -138,7 +139,7 @@ class TestEggInfo:
         ei.initialize_options()
         ei.save_version_info(setup_cfg)
 
-        with open(setup_cfg, 'r') as f:
+        with open(setup_cfg, 'r', encoding="utf-8") as f:
             content = f.read()
 
         assert '[egg_info]' in content
@@ -212,13 +213,9 @@ class TestEggInfo:
         with pytest.raises(AssertionError) as exc:
             self._run_egg_info_command(tmpdir_cwd, env)
 
-        # Hopefully this is not too fragile: the only argument to the
-        # assertion error should be a traceback, ending with:
-        #     ValueError: ....
-        #
-        #     assert not 1
-        tb = exc.value.args[0].split('\n')
-        assert tb[-3].lstrip().startswith('ValueError')
+        # The only argument to the assertion error should be a traceback
+        # containing a ValueError
+        assert 'ValueError' in exc.value.args[0]
 
     def test_rebuilt(self, tmpdir_cwd, env):
         """Ensure timestamps are updated when the command is re-run."""
@@ -250,7 +247,7 @@ class TestEggInfo:
         self._run_egg_info_command(tmpdir_cwd, env)
         egg_info_dir = os.path.join('.', 'foo.egg-info')
         sources_txt = os.path.join(egg_info_dir, 'SOURCES.txt')
-        with open(sources_txt) as f:
+        with open(sources_txt, encoding="utf-8") as f:
             assert 'docs/usage.rst' in f.read().split('\n')
 
     def _setup_script_with_requires(self, requires, use_setup_cfg=False):
@@ -491,7 +488,7 @@ class TestEggInfo:
         egg_info_dir = os.path.join('.', 'foo.egg-info')
         requires_txt = os.path.join(egg_info_dir, 'requires.txt')
         if os.path.exists(requires_txt):
-            with open(requires_txt) as fp:
+            with open(requires_txt, encoding="utf-8") as fp:
                 install_requires = fp.read()
         else:
             install_requires = ''
@@ -537,8 +534,8 @@ class TestEggInfo:
             env=environ,
         )
         egg_info_dir = os.path.join('.', 'foo.egg-info')
-        with open(os.path.join(egg_info_dir, 'PKG-INFO')) as pkginfo_file:
-            pkg_info_lines = pkginfo_file.read().split('\n')
+        with open(os.path.join(egg_info_dir, 'PKG-INFO'), encoding="utf-8") as fp:
+            pkg_info_lines = fp.read().split('\n')
         assert 'Provides-Extra: foobar' in pkg_info_lines
         assert 'Metadata-Version: 2.1' in pkg_info_lines
 
@@ -556,8 +553,8 @@ class TestEggInfo:
             env=environ,
         )
         egg_info_dir = os.path.join('.', 'foo.egg-info')
-        with open(os.path.join(egg_info_dir, 'PKG-INFO')) as pkginfo_file:
-            pkg_info_text = pkginfo_file.read()
+        with open(os.path.join(egg_info_dir, 'PKG-INFO'), encoding="utf-8") as fp:
+            pkg_info_text = fp.read()
         assert 'Provides-Extra:' not in pkg_info_text
 
     @pytest.mark.parametrize(
@@ -635,8 +632,7 @@ class TestEggInfo:
         )
         egg_info_dir = os.path.join('.', 'foo.egg-info')
 
-        with open(os.path.join(egg_info_dir, 'SOURCES.txt')) as sources_file:
-            sources_text = sources_file.read()
+        sources_text = Path(egg_info_dir, "SOURCES.txt").read_text(encoding="utf-8")
 
         if license_in_sources:
             assert 'LICENSE' in sources_text
@@ -848,8 +844,8 @@ class TestEggInfo:
         )
         egg_info_dir = os.path.join('.', 'foo.egg-info')
 
-        with open(os.path.join(egg_info_dir, 'SOURCES.txt')) as sources_file:
-            sources_lines = list(line.strip() for line in sources_file)
+        sources_text = Path(egg_info_dir, "SOURCES.txt").read_text(encoding="utf-8")
+        sources_lines = [line.strip() for line in sources_text.splitlines()]
 
         for lf in incl_licenses:
             assert sources_lines.count(lf) == 1
@@ -1032,8 +1028,8 @@ class TestEggInfo:
         )
         egg_info_dir = os.path.join('.', 'foo.egg-info')
 
-        with open(os.path.join(egg_info_dir, 'SOURCES.txt')) as sources_file:
-            sources_lines = list(line.strip() for line in sources_file)
+        sources_text = Path(egg_info_dir, "SOURCES.txt").read_text(encoding="utf-8")
+        sources_lines = [line.strip() for line in sources_text.splitlines()]
 
         for lf in incl_licenses:
             assert sources_lines.count(lf) == 1
@@ -1064,8 +1060,8 @@ class TestEggInfo:
             pypath=os.pathsep.join([env.paths['lib'], str(tmpdir_cwd)]),
         )
         egg_info_dir = os.path.join('.', 'foo.egg-info')
-        with open(os.path.join(egg_info_dir, 'PKG-INFO')) as pkginfo_file:
-            pkg_info_lines = pkginfo_file.read().split('\n')
+        with open(os.path.join(egg_info_dir, 'PKG-INFO'), encoding="utf-8") as fp:
+            pkg_info_lines = fp.read().split('\n')
         license_file_lines = [
             line for line in pkg_info_lines if line.startswith('License-File:')
         ]
@@ -1085,8 +1081,8 @@ class TestEggInfo:
             data_stream=1,
         )
         egg_info_dir = os.path.join('.', 'foo.egg-info')
-        with open(os.path.join(egg_info_dir, 'PKG-INFO')) as pkginfo_file:
-            pkg_info_lines = pkginfo_file.read().split('\n')
+        with open(os.path.join(egg_info_dir, 'PKG-INFO'), encoding="utf-8") as fp:
+            pkg_info_lines = fp.read().split('\n')
         # Update metadata version if changed
         assert self._extract_mv_version(pkg_info_lines) == (2, 1)
 
@@ -1111,8 +1107,8 @@ class TestEggInfo:
             env=environ,
         )
         egg_info_dir = os.path.join('.', 'foo.egg-info')
-        with open(os.path.join(egg_info_dir, 'PKG-INFO')) as pkginfo_file:
-            pkg_info_lines = pkginfo_file.read().split('\n')
+        with open(os.path.join(egg_info_dir, 'PKG-INFO'), encoding="utf-8") as fp:
+            pkg_info_lines = fp.read().split('\n')
         expected_line = 'Description-Content-Type: text/markdown'
         assert expected_line in pkg_info_lines
         assert 'Metadata-Version: 2.1' in pkg_info_lines
@@ -1132,8 +1128,8 @@ class TestEggInfo:
             data_stream=1,
         )
         egg_info_dir = os.path.join('.', 'foo.egg-info')
-        with open(os.path.join(egg_info_dir, 'PKG-INFO')) as pkginfo_file:
-            pkg_info_lines = pkginfo_file.read().split('\n')
+        with open(os.path.join(egg_info_dir, 'PKG-INFO'), encoding="utf-8") as fp:
+            pkg_info_lines = fp.read().split('\n')
         assert 'Metadata-Version: 2.1' in pkg_info_lines
         assert '' == pkg_info_lines[-1]  # last line should be empty
         long_desc_lines = pkg_info_lines[pkg_info_lines.index('') :]
@@ -1164,8 +1160,8 @@ class TestEggInfo:
             env=environ,
         )
         egg_info_dir = os.path.join('.', 'foo.egg-info')
-        with open(os.path.join(egg_info_dir, 'PKG-INFO')) as pkginfo_file:
-            pkg_info_lines = pkginfo_file.read().split('\n')
+        with open(os.path.join(egg_info_dir, 'PKG-INFO'), encoding="utf-8") as fp:
+            pkg_info_lines = fp.read().split('\n')
         expected_line = 'Project-URL: Link One, https://example.com/one/'
         assert expected_line in pkg_info_lines
         expected_line = 'Project-URL: Link Two, https://example.com/two/'
@@ -1181,8 +1177,8 @@ class TestEggInfo:
             data_stream=1,
         )
         egg_info_dir = os.path.join('.', 'foo.egg-info')
-        with open(os.path.join(egg_info_dir, 'PKG-INFO')) as pkginfo_file:
-            pkg_info_lines = pkginfo_file.read().split('\n')
+        with open(os.path.join(egg_info_dir, 'PKG-INFO'), encoding="utf-8") as fp:
+            pkg_info_lines = fp.read().split('\n')
         assert 'License: MIT' in pkg_info_lines
 
     def test_license_escape(self, tmpdir_cwd, env):
@@ -1196,8 +1192,8 @@ class TestEggInfo:
             data_stream=1,
         )
         egg_info_dir = os.path.join('.', 'foo.egg-info')
-        with open(os.path.join(egg_info_dir, 'PKG-INFO')) as pkginfo_file:
-            pkg_info_lines = pkginfo_file.read().split('\n')
+        with open(os.path.join(egg_info_dir, 'PKG-INFO'), encoding="utf-8") as fp:
+            pkg_info_lines = fp.read().split('\n')
 
         assert 'License: This is a long license text ' in pkg_info_lines
         assert '        over multiple lines' in pkg_info_lines
@@ -1215,8 +1211,8 @@ class TestEggInfo:
             env=environ,
         )
         egg_info_dir = os.path.join('.', 'foo.egg-info')
-        with open(os.path.join(egg_info_dir, 'PKG-INFO')) as pkginfo_file:
-            pkg_info_lines = pkginfo_file.read().split('\n')
+        with open(os.path.join(egg_info_dir, 'PKG-INFO'), encoding="utf-8") as fp:
+            pkg_info_lines = fp.read().split('\n')
         assert 'Requires-Python: >=2.7.12' in pkg_info_lines
         assert self._extract_mv_version(pkg_info_lines) >= (1, 2)
 
@@ -1239,7 +1235,7 @@ class TestEggInfo:
 
         assert 'setup.py' in egg_info_instance.filelist.files
 
-        with open(egg_info_instance.egg_info + "/SOURCES.txt") as f:
+        with open(egg_info_instance.egg_info + "/SOURCES.txt", encoding="utf-8") as f:
             sources = f.read().split('\n')
             assert 'setup.py' in sources
 
@@ -1276,8 +1272,8 @@ class TestEggInfo:
         })
         self._run_egg_info_command(tmpdir_cwd, env)
         egg_info_dir = os.path.join('.', 'foo.egg-info')
-        with open(os.path.join(egg_info_dir, 'PKG-INFO')) as pkginfo_file:
-            pkg_info_lines = pkginfo_file.read().split('\n')
+        with open(os.path.join(egg_info_dir, 'PKG-INFO'), encoding="utf-8") as fp:
+            pkg_info_lines = fp.read().split('\n')
         assert 'Version: 0.0.0.dev0' in pkg_info_lines
 
 
